@@ -35,12 +35,13 @@ func (tb *tokenBucket) startSignalHandler() {
 
 				tb.toggledOff = !tb.toggledOff
 				tb.curr, tb.prev = tb.prev, tb.curr
-				s := "disabled"
+				s, limit := "disabled", "off"
 				if !tb.curr._isOff() {
 					s = "enabled"
+					limit = tb.currLimit.Bandwidth.String()
 				}
 
-				fs.Logf(nil, "Bandwidth limit %s by user", s)
+				fs.Logf(nil, "Bandwidth limit %s by user (now %s)", s, limit)
 			}()
 		}
 	}()
